------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Manifest           --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local class = require( "shared.class" )

-- Seed random number generator.
math.randomseed( os.time() )
math.random(); math.random(); math.random()

-- globals --
instance = nil

-- LuaEngine --
LuaEngine = class.new
{
	platform = nil,
	chunks   = nil,
	paths    = nil,
	product  = "",
	theme    = ""
}

-- The created method.
function LuaEngine:created( owner )	
	-- Create the tables.
	self.platform = {}
	
	-- Figure out the device type.
	do
		self.platform.device = "android"
	
		print( "device: " .. self.platform.device )
	end
	
	-- Load device-specific constants.
	do
		self.platform.constants = require( "platform." .. self.platform.device .. ".constants" )
		
		owner.delta_time_cap = self.platform.constants.delta_time_cap
	end
	
	-- Randomly set theme on startup.
	if self.product == "deluxe" then
		local themes = { "classic", "jungle", "pirates" }
		
		self.theme = themes[ math.random( 1, #themes ) ]
	else
		self.theme = "classic"
	end
	
	-- Make ourself global.
	instance = self
	
	-- Precache shared assets.
	do
		-- Setup paths.
		self.paths = 
		{
			scripts_shared  = "shared",
			textures_shared = "texture://" .. self.platform.device .. "/shared/",
			sounds_shared   = "sound://shared/"
		}
	
		local precache = require( "shared.precache" )
		local assets   = require( "shared.assets" )
		
		precache.load( assets )
	end
	
	sendMessage("hidesplash")
	self:spawnMenuGame()
	--self:spawnMainGame( "classic" )
end

-- Spawn a menu game.
function LuaEngine:spawnMenuGame()
	sendMessage("menu")

	-- Unload game assets.
	if self.chunks ~= nil then
		self.chunks.precache.unload( self.chunks.assets )
	end
	
	-- Setup paths.
	self.paths = 
	{
		scripts_shared   = "shared",
		scripts_product  = "products." .. self.product,
		textures_shared  = "texture://" .. self.platform.device .. "/shared/",
		textures_product = "texture://" .. self.platform.device .. "/products/" .. self.product .. "/",
		music_shared     = "music://",
		sounds_shared    = "sound://shared/"
	}
	
	-- Clear all preloaded modules.
	for k,v in pairs( package.loaded ) do
		package.loaded[ k ] = nil
	end
	
	-- Collect garbage.
	collectgarbage( "collect" )
	
	-- Load the chunks.
	require( "products." .. self.product .. ".chunks" )
	
	-- Overrides.
	if self.platform.constants.menu_overrides ~= nil then
		self.platform.constants.menu_overrides()
	end
	
	-- Spawn the menu game.
	self.owner:pushGame( self.chunks.game.spawn() )
end

-- Spawn a game.

function LuaEngine:spawnMainGame( theme, replay )
	sendMessage("newgame")
	
	replay = replay or false

	-- Unload menu assets.
	if replay == false and self.chunks ~= nil then
		self.chunks.precache.unload( self.chunks.assets )
	end
	
	-- Setup the theme.
	self.theme = theme
	
	-- Setup paths.
	self.paths = 
	{
		scripts_shared   = "shared",
		scripts_theme    = "themes." .. theme,
		textures_shared  = "texture://" .. self.platform.device .. "/shared/",
		textures_theme   = "texture://" .. self.platform.device .. "/themes/" .. theme .. "/",
		meshes           = "mesh://themes/" .. theme .. "/",
		music_theme      = "music://themes/" .. theme .. "/",
		sounds_shared    = "sound://shared/",
		sounds_theme     = "sound://themes/" .. theme .. "/"
	}
	
	-- Clear all preloaded modules.
	for k,v in pairs( package.loaded ) do
		package.loaded[ k ] = nil
	end

	-- Load the chunks.
	require( "themes." .. theme .. ".chunks" )
	
	-- Overrides.
	if self.platform.constants.game_overrides ~= nil then
		self.platform.constants.game_overrides()
	end
	
	-- Precache.
	if replay == false then
		self.chunks.precache.load( self.chunks.assets )
	end
	
	-- Collect garbage.
	collectgarbage( "collect" )
	
	-- Spawn the game.
	do
		local game = self.owner:pushGame( self.chunks.game.spawn() )
	
		game.lua:intro( replay )
	end
end

-- Bind the engine.
function bindEngine( owner, product )
	local engine = LuaEngine:new( owner )
	
	-- Set the product.
	engine.lua.product = product
end

-- setting original onMenuButton function
function LuaEngine:onMenuButton()
	print("LuaEngine:onMenuButton "..tostring(instance));
end
function LuaEngine:onBackButton()
	print("LuaEngine:onBackButton "..tostring(instance));
end

