------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Constants          --
------------------------

-- module --
module(...,package.seeall)

-- How tall are ads?
ad_height      = 50.0

local world_size = v2f( 320.0, 480.0 )
local world_aspect = world_size.y/world_size.x

local screen_size = v2f( getDisplayWidth(), getDisplayHeight() );
local screen_aspect = screen_size.y/screen_size.x

local cropped_size
local cropped_offset

-- if the screen aspect is too much taller than the world's, then
-- squeeze the screen into 
if screen_aspect/world_aspect > 1.1 then
	local ratio = screen_size.x/world_size.x ; 
	cropped_size = v2f( screen_size.x, screen_size.y-(ad_height*ratio) );
	cropped_offset = v2f( 0, ad_height*ratio )
else
	cropped_size = screen_size
	cropped_offset = v2f( 0, 0 )
end

local adjusted_size = v2f( world_size.x, screen_size.y/screen_size.x * world_size.x );

print(screen_size);

-- scene camera info
scene = 
{
	viewport_offset = v2f( 0.0, 0.0 ),
	viewport_size   = screen_size,
	viewport_cropped= cropped_size,
	cropped_offset	= cropped_offset,
	screen_size     = screen_size,
	world_size      = world_size,
	clipping_planes = v2f( 500.0, -500.0 )
}

-- window camera info
window = 
{
	viewport_offset = v2f( 0.0, 0.0 ),
	viewport_size   = screen_size,
	viewport_cropped= cropped_size,
	adjusted_size	= adjusted_size,
	cropped_offset	= cropped_offset,
	screen_size     = screen_size,
	world_size      = world_size,
	clipping_planes = v2f( 500.0, -500.0 )
}

-- other
clear_color    = colorf( 1.0, 1.0, 1.0, 1.0 )
clear_color_on = false
clear_depth_on = true
delta_time_cap = 1.0 / 25.0

-- game specific
wall_tile_size = v2f( 32.0, 50.0 )

-- Game overrides.
function game_overrides()
	local engine = engine.instance
	local chunks = engine.chunks
	local assets = chunks.assets
	
	-- Jungle.
	if engine.theme == "jungle" then
		-- If this is a 3G or less, disable foliage.
		if device.getPerformance() < device.DEVICE_PERFORMANCE_PROFILE_FAST then
			assets.textures.foliage1           = nil
			assets.textures.foliage2           = nil
			assets.textures.foliage3           = nil
			assets.meshes.foliage1             = nil
			assets.meshes.foliage2             = nil
			assets.meshes.foliage3             = nil
			chunks.scenarios.scenarios.foliage = nil
		end
	end
end
