------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- LuaMenuGame        --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine    = engine.instance
local chunks    = engine.chunks
local constants = engine.platform.constants
local pool      = chunks.pool
local assets    = chunks.assets

-- LuaMenuGame --
LuaMenuGame = chunks.class.new()

-- The spawner.
spawn = chunks.class.spawner( Game, LuaMenuGame )

-- The created method.
function LuaMenuGame:created( game )
	-- Set clearing info.
	game.clear_color    = constants.clear_color
	game.clear_color_on = constants.clear_color_on
	game.clear_depth_on = constants.clear_depth_on
	
	-- Spawn root.
	self.root = game:getScene():spawn( ActorBase() )
	
	-- Scene camera.
	do
		local camera = game:getScene():spawn( OrthographicCamera() )
		
		camera.viewport_offset = constants.scene.viewport_offset
		camera.viewport_size   = constants.scene.viewport_cropped
		--camera.viewport_size   = constants.scene.viewport_size
		camera.screen_size     = constants.scene.screen_size
		camera.world_size      = constants.scene.world_size
		camera.clipping_planes = constants.scene.clipping_planes
		
		game.scene_camera = camera
	end
	
	-- Window camera.
	do
		local camera = game:getWindow():spawn( OrthographicCamera() )
		
		camera.viewport_offset = constants.window.cropped_offset
		camera.viewport_size   = constants.window.viewport_cropped
		--camera.viewport_size   = constants.window.viewport_size
		camera.screen_size     = constants.window.screen_size
		camera.world_size      = constants.window.world_size
		camera.clipping_planes = constants.window.clipping_planes
		
		game.window_camera = camera
	end
	
	-- Spawn main menu.
	do
		local userdata = UserData.get()
		
		if userdata:getShouldShowPapaya() then
			game:getWindow():spawn( chunks.papaya.spawn() )
		else
			game:getWindow():spawn( chunks.main.spawn() )
		end
	end
	
	-- Start music.
	do
		local music = Audio.get().music
		
		music:clearPlaylist()
		music:addToPlaylist( assets.music.main )
		music:play()
	end
end

-- The replay event.
function LuaMenuGame:onPlay( theme )
	local game = self.owner
	
	engine:spawnMainGame( theme )
	game:destroy()
end
