------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- LuaMainMenu        --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine    = engine.instance
local constants = engine.platform.constants
local chunks    = engine.chunks
local assets    = chunks.assets
local pool      = chunks.pool
local textures  = chunks.textures
local fade      = chunks.fade
local events    = chunks.events

-- LuaMainMenu --
LuaMainMenu = chunks.class.inherit( chunks.window.LuaWindow )()
	
-- The spawner.
spawn = chunks.class.spawner( Dialog, LuaMainMenu )

-- The created method.
function LuaMainMenu:created( owner )
	local game     = owner:getGame()
	local x_offset = 5.0
	local y_offset = constants.ad_height + 10.0
	
	-- Background.
	do
		textures.setTexture( owner, assets.textures.main )
	end
		
	-- Options.
	do
		local on_release = function( inner )
			local callback = function( o )
				game:getWindow():spawn( chunks.options.spawn() )
				owner:destroy()
			end
			
			fade.fade_out( owner, callback )
		end
		
		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, 
		                       pool.get_v3f( x_offset, y_offset , 1.0 ) )
		
		textures.setTexture( actor, assets.textures.options_button )
	end

	-- set up an onMenuButton function
	engine.onMenuButton = function() 
		engine.onMenuButton = function() end;
		game:getWindow():spawn( chunks.options.spawn() )
		owner:destroy()		
	end

	engine.onBackButton = function() sendMessage("quit");	end

	-- Generates a function to play the specified theme.
	local play_game = function( theme )
		return function( outer )
			local userdata = UserData.get()
			local callback = function( inner )

				-- If this is the first time they've 
				-- played, show the tutorial menu.
				if userdata.first_time_played then
					local tutorial = game:getWindow():spawn( chunks.tutorial.spawn() )
						
					tutorial.lua:play( theme )
					owner:destroy()
					userdata.first_time_played = false
					userdata:flush()
				else
					game.lua:onPlay( theme )
				end
			end
			
			-- Change fade accordingly.
			if userdata.first_time_played then
				fade.fade_out( owner, callback )
			else
				fade.fade_out_loading( owner, callback )
			end

			events.on_main_menu_fadeout( game )
		end
	end
	
	-- Play.
	do
		local actor  = self:addButton( play_game( "classic" ) )
		actor.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, 
		                       pool.get_v3f( x_offset + 2.0, y_offset + 38.0, 1.0 ) )
		
		textures.setTexture( actor, assets.textures.play_button )
		
		-- Setup a bobbing action.
		do
			local l = LoopAction()
			
			l:addAction( ScaleAction( 0.4, InterpAction.Smooth, pool.get_v3f( 1.1, 1.1, 1.0 ) ) )
			l:addAction( ScaleAction( 0.4, InterpAction.Smooth, pool.get_v3f( 1.0, 1.0, 1.0 ) ) )
			
			actor:addAction( l )
		end
	end
	
	-- Leaderboards.
	do
		local on_release = function( inner )
			events.on_leaderboard_dashboard( game )
		end
		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BR, Anchor.Anchor_BR, pool.get_v3f( -x_offset, y_offset, 1.0 ) )
		
		textures.setTexture( actor, assets.textures.leaderboards_button )
	end

	-- Exit
	do
		local on_release = function( inner )
			sendMessage("exit")
		end
		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_TL, Anchor.Anchor_BL, pool.get_v3f( 249, 480, 1.0 ) )

		textures.setTexture( actor, assets.textures.exit_button )
	end
	
	-- Fade in.
	do
		fade.fade_in( owner )
	end
end



