------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- LuaOptionsMenu     --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine    = engine.instance
local constants = engine.platform.constants
local chunks    = engine.chunks
local assets    = chunks.assets
local pool      = chunks.pool
local textures  = chunks.textures
local fade      = chunks.fade
local events    = chunks.events

-- LuaOptionsMenu --
LuaOptionsMenu = chunks.class.inherit( chunks.window.LuaWindow )
{
	volume_box_offset = v2f( 60.0, 44.0 ),
	score_offset      = v2f( 20.0, -23.0 ),
	button_box_offset = v2f( -61.0, -60.0 )
}
	
-- The spawner.
spawn = chunks.class.spawner( Dialog, LuaOptionsMenu )

-- The created method.
function LuaOptionsMenu:created( owner )
	local game     = owner:getGame()
	local x_offset = 5.0
	local y_offset = constants.ad_height + 10.0
	
	-- Background.
	do
		textures.setTexture( owner, assets.textures.options )
	end
	
	-- Back.
	do
		local on_release = function( inner )
			local callback = function( o )
				game:getWindow():spawn( chunks.main.spawn() )
				owner:destroy()
			end
			
			fade.fade_out( owner, callback )
		end
		
		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, pool.get_v3f( x_offset, y_offset, 1.0 ) )
		
		textures.setTexture( actor, assets.textures.back_button )
	end
	
	-- handle back button
	engine.onBackButton = function() 
		engine.onBackButton = function() end;
		game:getWindow():spawn( chunks.main.spawn() )
		owner:destroy()	
	end

	local volume_box = nil
	
	-- Box for volume buttons.
	do
		volume_box         = owner:spawn( chunks.window.spawn( Window() ) )
		volume_box.size    = pool.get_v2f( 100.0, 100.0 )		
		volume_box.hidden  = true
		volume_box.anchor  = Anchor( Anchor.Anchor_BL, Anchor.Anchor_C, 
		                             pool.get_v3f( self.volume_box_offset.x, self.volume_box_offset.y, 1.0 ) )
	end
	
	-- Function to set the volume texture.
	local set_volume_texture = function( actor, on )
		if on then
			textures.setTexture( actor, assets.textures.on_button )
		else
			textures.setTexture( actor, assets.textures.off_button )
		end	
	end
	
	-- Music volume.
	do
		local on_release = function( inner )
			local music_on = not Audio.get().music_on
			
			Audio.get().music_on = music_on
			
			set_volume_texture( inner, music_on )
		end
		
		local actor  = volume_box.lua:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, pool.get_v3f( 0.0, 0.0, 0.0 ) )
		
		set_volume_texture( actor, Audio.get().music_on )
	end
	
	-- Sound volume.
	do
		local on_release = function( inner )
			local sound_on = not Audio.get().sound_on
			
			Audio.get().sound_on = sound_on
			
			set_volume_texture( inner, sound_on )
		end
		
		local actor  = volume_box.lua:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, pool.get_v3f( 0.0, 55.0, 0.0 ) )
		
		set_volume_texture( actor, Audio.get().sound_on )
	end
	
	-- Score.
	do
		local actor = owner:spawn( chunks.ticker.spawn() )
		
		actor.location = pool.get_v3f( self.score_offset.x, self.score_offset.y, 1.0 )
		actor.color    = pool.get_colorf( 1.0, 0.0, 0.0, 1.0 )
		actor.value    = UserData.get():getHighScore( "classic" )
	end
	
	local button_box = nil
	
	-- Box for three middle buttons.
	do
		button_box         = owner:spawn( chunks.window.spawn( Window() ) )
		button_box.size    = pool.get_v2f( 100.0, 100.0 )		
		button_box.hidden  = true
		button_box.anchor  = Anchor( Anchor.Anchor_TL, Anchor.Anchor_C, 
		                             pool.get_v3f( self.button_box_offset.x, self.button_box_offset.y, 1.0 ) )
	end
	
	-- Tutorial.
	do
		local on_release = function( inner )
			local callback = function( o )
				local tutorial = game:getWindow():spawn( chunks.tutorial.spawn() )
				
				tutorial.lua:options()
				owner:destroy()
			end
			
			fade.fade_out( owner, callback )
		end
		
		local actor  = button_box.lua:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_TL, Anchor.Anchor_TL, pool.get_v3f( 0.0, 0.0, 0.0 ) )
		
		textures.setTexture( actor, assets.textures.tutorial_button )
	end
	
	-- Credits.
	do
		local on_release = function( inner )
			local callback = function( o )
				game:getWindow():spawn( chunks.credits.spawn() )
				owner:destroy()
			end
			
			fade.fade_out( owner, callback )
		end
		
		local actor  = button_box.lua:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_TL, Anchor.Anchor_TL, pool.get_v3f( 0.0, -40.0, 0.0 ) )
		
		textures.setTexture( actor, assets.textures.credits_button )
	end
	
	--[[	
	-- Ad buyout.
	do
		local on_release = function( inner )
			local callback = function( o )
				game:getWindow():spawn( chunks.adbuyout.spawn() )
				owner:destroy()
			end
			
			fade.fade_out( owner, callback )
		end
		
		local actor  = button_box.lua:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_TL, Anchor.Anchor_TL, pool.get_v3f( 1.0, -80.0, 0.0 ) )
		
		textures.setTexture( actor, assets.textures.adbuyout_button )	
	end
	--]]

	-- Fade in.
	do
		fade.fade_in( owner )
	end
	
	-- Analytics.
	events.on_options_menu( game )
end


