------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- LuaPapayaMenu     --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine    = engine.instance
local constants = engine.platform.constants
local chunks    = engine.chunks
local assets    = chunks.assets
local pool      = chunks.pool
local textures  = chunks.textures
local fade      = chunks.fade
local events    = chunks.events

-- LuaPapayaMenu --
LuaPapayaMenu = chunks.class.inherit( chunks.window.LuaWindow )()
	
-- The spawner.
spawn = chunks.class.spawner( Dialog, LuaPapayaMenu )

-- The created method.
function LuaPapayaMenu:created( owner )
	local game     = owner:getGame()
	local y_offset = constants.ad_height

	-- Background.
	do
		textures.setTexture( owner, assets.textures.papaya_intro )
	end

	-- No Thanks.
	do
		local on_release = function( inner )
			local callback = function( o )
				game:getWindow():spawn( chunks.main.spawn() )
				owner:destroy()
			end
			
			fade.fade_out( owner, callback )
		end
		
		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, pool.get_v3f( 34, 480-381-y_offset, 1.0 ) )
		actor.color  = pool.get_colorf( 1.0, 1.0, 1.0, 0.0 )
		actor.on_enter = function() end;
		actor.on_exit = function() end;
		
		textures.setTexture( actor, { path="builtin://white", size=v2f( 251,48 ) } )
	end
	
	-- Papaya
	do

		local on_release = function( inner )
			local callback = function( o )
				game:getWindow():spawn( chunks.main.spawn() )
				owner:destroy()	
				sendMessage("leaderboard")
			end

			fade.fade_out( owner, callback )
		end

		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, pool.get_v3f( 87, 480-308-y_offset, 1.0 ) )
		actor.color  = pool.get_colorf( 1.0, 1.0, 1.0, 0.0 )
		actor.on_enter = function() end;
		actor.on_exit = function() end;

		textures.setTexture( actor, { path="builtin://white", size=v2f( 142,55 ) } )
		
	end

	-- handle back button
	engine.onBackButton = function() 
		engine.onBackButton = function() end;
		game:getWindow():spawn( chunks.main.spawn() )
		owner:destroy()	
	end

	-- Fade in.
	do
		fade.fade_in( owner )
	end
	
	-- Analytics.
	sendMessage("papaya")

	events.on_credits_menu( game )
end



