------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- LuaTutorialMenu    --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine    = engine.instance
local constants = engine.platform.constants
local chunks    = engine.chunks
local assets    = chunks.assets
local pool      = chunks.pool
local textures  = chunks.textures
local fade      = chunks.fade
local events    = chunks.events

-- LuaTutorialMenu --
LuaTutorialMenu = chunks.class.inherit( chunks.window.LuaWindow )()
	
-- The spawner.
spawn = chunks.class.spawner( Dialog, LuaTutorialMenu )

-- The created method.
function LuaTutorialMenu:created( owner )
	local game     = owner:getGame()
	local x_offset = 5.0
	local y_offset = -5.0
	
	if constants.scene.screen_size == constants.scene.viewport_cropped then
		sendMessage("hideads")
	end

	-- Background.
	do
		textures.setTexture( owner, assets.textures.tutorial )
	end
	
	-- Fade in.
	do
		fade.fade_in( owner )
	end
	
	-- handle back button
	engine.onBackButton = function() 
		engine.onBackButton = function() end;
		game:getWindow():spawn( chunks.main.spawn() )
		owner:destroy()	
	end

	-- Analytics.
	events.on_tutorial_menu( game )
end

-- The options tutorial menu.
function LuaTutorialMenu:options()
	local owner    = self.owner
	local game     = owner:getGame()
	local x_offset = 5.0
	local y_offset = -5.0
	
	-- Back.
	do
		local on_release = function( inner )
			local callback = function( o )
				game:getWindow():spawn( chunks.options.spawn() )
				owner:destroy()
			end
			
			fade.fade_out( owner, callback )
		end
		
		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_TL, Anchor.Anchor_TL, pool.get_v3f( x_offset, y_offset, 1.0 ) )
		
		textures.setTexture( actor, assets.textures.back_button )
	end
end

-- The play tutorial menu.
function LuaTutorialMenu:play( theme )
	local owner    = self.owner
	local game     = owner:getGame()
	local x_offset = -10.0
	local y_offset = 15.0
	local delay    = 0.35
	
	-- Play.
	do
		local on_release = function( inner )
			local callback = function( o )
				game.lua:onPlay( theme )
			end
			
			fade.fade_out_loading( owner, callback )
		end
		
		local actor  = self:addButton( on_release )
		actor.anchor = Anchor( Anchor.Anchor_BR, Anchor.Anchor_BR, pool.get_v3f( x_offset, y_offset, 1.0 ) )
		
		textures.setTexture( actor, assets.textures.tutorial_play_button )
		
		-- Actions.
		do
			local l = LoopAction()
			
			l:addAction( ScaleAction( delay, InterpAction.Smooth,
								  pool.get_v3f( 1.1, 1.1, 1.0 ) ) )
			l:addAction( ScaleAction( delay, InterpAction.Smooth,
								  pool.get_v3f( 1.0, 1.0, 1.0 ) ) )
			
			actor:addAction( l )
		end
	end
end


