------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Assets             --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine = engine.instance
local chunks = engine.chunks

--------------
-- textures --
--------------

local textures_shared = engine.paths.textures_shared

textures = {}

-- hud --
textures.digits              = { path = textures_shared .. "hud/digits", size = v2f( 16.0, 22.0 ) }
textures.score_bar           = { path = textures_shared .. "hud/score_bar", size = v2f( 121.0, 32.0 ) }
textures.pause_button        = { path = textures_shared .. "hud/pause_button", size = v2f(  32.0, 31.0 ) }
textures.continue_button     = { path = textures_shared .. "hud/continue_button", size = v2f( 66.0, 66.0 ) }
textures.menu_button         = { path = textures_shared .. "hud/menu_button", size = v2f( 62.0, 35.0 ) }
textures.death_menu          = { path = textures_shared .. "hud/death_menu", size = v2f( 249.0, 249.0 ) }
textures.leaderboards_button = { path = textures_shared .. "hud/gamecenter_button", size = v2f( 54.0, 54.0 ) }
textures.facebook_button     = { path = textures_shared .. "hud/facebook_button", size = v2f( 50.0, 50.0 ) }
textures.twitter_button      = { path = textures_shared .. "hud/twitter_button", size = v2f( 50.0, 50.0 ) }
textures.email_button        = { path = textures_shared .. "hud/email_button", size = v2f( 50.0, 50.0 ) }
textures.replay_button       = { path = textures_shared .. "hud/replay_button", size = v2f( 166.0, 62.0 ) }
textures.bonus_meter_glow    = { path = textures_shared .. "hud/bonus_meter_glow", size = v2f( 64.0, 64.0 ) }
textures.loading             = { path = "builtin://white", size = v2f( 320, 480 ) }

-- Leaderboards button for classic game.
if engine.product == "classic" then
	textures.leaderboards_button.path = textures_shared .. "hud/leaderboards_button"
end

-- ninja --
textures.ninja_climbing = { path = textures_shared .. "ninja/climbing", size = v2f( 40.0, 40.0 ), collides = true }
textures.ninja_jumping  = { path = textures_shared .. "ninja/jumping", size = v2f( 100.0, 100.0 ), collides = true }
textures.ninja_falling  = { path = textures_shared .. "ninja/falling", size = v2f( 55.0, 55.0 ), collides = true }
textures.shield         = { path = textures_shared .. "ninja/shield", size = v2f( 128.0, 128.0 ) }

-- enemies --
textures.shieldpack = { path = textures_shared .. "enemies/shieldpack", size = v2f( 60.0, 60.0 ), collides = true }

-- particles --
textures.particles_shield = { path = textures_shared .. "particles/shield", size = v2f( 8.0, 8.0 ) }
textures.particles_spark  = { path = textures_shared .. "particles/spark", size = v2f( 11.0, 11.0 ) }

-- effects --
textures.effects_slice = { path = textures_shared .. "effects/slice", size = v2f( 64.0, 64.0 ) }

------------
-- sounds --
------------

local sounds_shared = engine.paths.sounds_shared

sounds = {}

-- ui --
sounds.click = { path = sounds_shared .. "click.caf" } 

-- game --
sounds.die = { path = sounds_shared .. "die.caf", priority = 80.0 }

-- ninja --
sounds.footsteps  = { path = sounds_shared .. "ninja/footsteps.caf", priority = 80.0, loops = true }
sounds.ninja_fall = 
{
	{ path = sounds_shared .. "ninja/fall_1.caf", priority = 80.0 },
	{ path = sounds_shared .. "ninja/fall_2.caf", priority = 80.0 },
	{ path = sounds_shared .. "ninja/fall_3.caf", priority = 80.0 }
}
sounds.ninja_jump =
{
	{ path = sounds_shared .. "ninja/jump_1.caf" },
	{ path = sounds_shared .. "ninja/jump_2.caf" },
	{ path = sounds_shared .. "ninja/jump_3.caf" },
	{ path = sounds_shared .. "ninja/jump_4.caf" },
	{ path = sounds_shared .. "ninja/jump_5.caf" },
	{ path = sounds_shared .. "ninja/jump_6.caf" },
	{ path = sounds_shared .. "ninja/jump_7.caf" },
	{ path = sounds_shared .. "ninja/jump_8.caf" },
	{ path = sounds_shared .. "ninja/jump_9.caf" },
	{ path = sounds_shared .. "ninja/jump_10.caf" }
}
sounds.ninja_land =
{
	{ path = sounds_shared .. "ninja/land_1.caf" },
	{ path = sounds_shared .. "ninja/land_2.caf" },
	{ path = sounds_shared .. "ninja/land_3.caf" },
	{ path = sounds_shared .. "ninja/land_4.caf" },
	{ path = sounds_shared .. "ninja/land_5.caf" },
	{ path = sounds_shared .. "ninja/land_6.caf" },
	{ path = sounds_shared .. "ninja/land_7.caf" },
	{ path = sounds_shared .. "ninja/land_8.caf" },
	{ path = sounds_shared .. "ninja/land_9.caf" },
	{ path = sounds_shared .. "ninja/land_10.caf" }
}

-- enemies --
sounds.shieldpack = { path = sounds_shared .. "shieldpack.caf", priority = 80.0 } 
sounds.explode    =
{
	{ path = sounds_shared .. "enemies/explode_1.caf" },
	{ path = sounds_shared .. "enemies/explode_2.caf" },
	{ path = sounds_shared .. "enemies/explode_3.caf" }
}
sounds.throw =
{
	{ path = sounds_shared .. "enemies/throw_1.caf" },
	{ path = sounds_shared .. "enemies/throw_2.caf" },
	{ path = sounds_shared .. "enemies/throw_3.caf" }
}
sounds.hit_enemy =
{
	{ path = sounds_shared .. "enemies/hit_enemy_1.caf" },
	{ path = sounds_shared .. "enemies/hit_enemy_2.caf" },
	{ path = sounds_shared .. "enemies/hit_enemy_3.caf" }
}
sounds.hit_overhang =
{
	{ path = sounds_shared .. "enemies/hit_overhang_1.caf" },
	{ path = sounds_shared .. "enemies/hit_overhang_2.caf" },
	{ path = sounds_shared .. "enemies/hit_overhang_3.caf" }
}

----------
-- misc --
----------

-- The attach point - sets up metatables for shared assets.
function attach( assets )
	setmetatable( assets.textures, { __index = textures } )
	setmetatable( assets.sounds,   { __index = sounds   } )
end



	

