------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Events             --
------------------------

-- NOTES --
-- This file contains public C++ events and
-- builds the appropriate context for them,
-- as well as dispatching them.

-- module --
module(...,package.seeall)

local engine = engine.instance
local chunks = engine.chunks

-- Builds an empty context.
local build_empty_context = function( _message )
	return
	{
		message = _message
	}
end

-- Builds a context.
local build_context = function( _message )
	return 
	{
		message  = _message,
		product  = engine.product,
		platform = engine.platform.device,
		theme    = engine.theme
	}
end	

-- Builds a social context.
local build_social_context = function( _message, game )
	return 
	{
		message  = _message,
		product  = engine.product,
		platform = engine.platform.device,
		theme    = engine.theme,
		score    = game.lua.height
	}
end	

-- Shows the more games panel.
function on_more_games( game )
	onGameEvent:publish( GameContext( game, build_empty_context( "more_games" ) ) )
end

-- Brings up the leaderboard dashboard.
function on_leaderboard_dashboard( game )
	onGameEvent:publish( GameContext( game, build_context( "leaderboard_dashboard" ) ) )
end

-- The user goes to the main menu.
function on_main_menu( game )
	onGameEvent:publish( GameContext( game, build_context( "main_menu" ) ) )
end

-- The main menu begins fading out
function on_main_menu_fadeout( game )
	onGameEvent:publish( GameContext( game, build_context( "main_menu_fadeout" ) ) )
end

-- The user goes to the options menu.
function on_options_menu( game )
	onGameEvent:publish( GameContext( game, build_context( "options_menu" ) ) )
end

-- The user goes to the tutorial menu.
function on_tutorial_menu( game )
	onGameEvent:publish( GameContext( game, build_context( "tutorial_menu" ) ) )
end

-- The user goes to the credits menu.
function on_credits_menu( game )
	onGameEvent:publish( GameContext( game, build_context( "credits_menu" ) ) )
end

-- The user started a game.
function on_start_game( game )
	onGameEvent:publish( GameContext( game, build_context( "start_game" ) ) )
end

-- The user quit a game.
function on_quit_game( game )
	onGameEvent:publish( GameContext( game, build_context( "quit_game" ) ) )
end

-- Brings up the leaderboard for the specified theme.
function on_leaderboard_theme( game )
	onGameEvent:publish( GameContext( game, build_social_context( "leaderboard_theme", game ) ) )
end

-- Brings up facebook.
function on_facebook( game )
	onGameEvent:publish( GameContext( game, build_social_context( "facebook", game ) ) )
end

-- Brings up twitter.
function on_twitter( game )
	onGameEvent:publish( GameContext( game, build_social_context( "twitter", game ) ) )
end

-- Brings up email.
function on_email( game )
	onGameEvent:publish( GameContext( game, build_social_context( "email", game ) ) )
end

-- The game over event.
function on_game_over( game )
	onGameEvent:publish( GameContext( game, build_social_context( "game_over", game ) ) )
end	

