------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Fade               --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine   = engine.instance
local chunks   = engine.chunks
local assets   = chunks.assets
local pool     = chunks.pool
local textures = chunks.textures

-- Fade in, then call a callback.
function fade_in( owner, callback )
	local game  = owner:getGame()
	local actor = owner:spawn( SpriteActor() )
	
	callback       = callback or function( inner ) end
	actor.texture  = "builtin://white"
	actor.location = pool.get_v3f( 0.0, 0.0, 100.0 )
	actor.size     = game.window_camera.world_size
	actor.color    = pool.get_colorf( 1.0, 1.0, 1.0, 1.0 )
	
	-- Actions.
	do
		local s = SequenceAction()
		
		s:addAction( AlphaAction( 0.5, InterpAction.Smooth, 0.0 ) )
		s:addAction( LuaAction( 0.0, callback ) )
		s:addAction( DestroyAction( 0.0 ) )
		
		actor:addAction( s )
	end
	
	return actor
end

-- Fade out, then call a callback.
function fade_out( owner, callback )
	local game  = owner:getGame()
	local actor = owner:spawn( SpriteActor() )
	
	callback       = callback or function( inner ) end
	actor.texture  = "builtin://white"
	actor.location = pool.get_v3f( 0.0, 0.0, 100.0 )
	actor.size     = game.window_camera.world_size
	actor.color    = pool.get_colorf( 1.0, 1.0, 1.0, 0.0 )
	
	-- Actions.
	do
		local s = SequenceAction()
		
		s:addAction( AlphaAction( 0.5, InterpAction.Smooth, 1.0 ) )
		s:addAction( LuaAction( 0.0, callback ) )
		
		actor:addAction( s )
	end
	
	return actor
end	

-- Fade in loading.
function fade_in_loading( owner, callback )
	local actor   = fade_in( owner, callback )
	local loading = actor:spawn( SpriteActor() )
	
	loading.location = pool.get_v3f( 0.0, 0.0, 1.0 )
	
	textures.setTexture( loading, assets.textures.loading )
end

-- Fade out loading.
function fade_out_loading( owner, callback )
	local actor   = fade_out( owner, callback )
	local loading = actor:spawn( SpriteActor() )
	
	loading.location = pool.get_v3f( 0.0, 0.0, 1.0 )
	
	textures.setTexture( loading, assets.textures.loading )
end

