------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Death Menu         --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine   = engine.instance
local chunks   = engine.chunks
local assets   = chunks.assets
local pool     = chunks.pool
local textures = chunks.textures
local sound    = chunks.sound
local events   = chunks.events

-- LuaDeathMenu --
LuaDeathMenu = chunks.class.inherit( chunks.window.LuaWindow )()

-- The spawner.
spawn = chunks.class.spawner( Dialog, LuaDeathMenu )

-- The created event.
function LuaDeathMenu:created( owner )
	local game = owner:getGame()
	
	-- Initialize owner.
	owner.location = pool.get_v3f( 0.0, 0.0, 10.0 )
	textures.setTexture( owner, assets.textures.death_menu )
	
	local score      = game.lua.height
	local high_score = game.lua.best_height
	
	-- Score text.
	do
		local text = owner:spawn( chunks.ticker.spawn() )
		
		text.location = pool.get_v3f( -40.0, 44.0, 1.0 )
		text.scale    = pool.get_v3f( 1.2, 1.2, 1.2 )
		text.color    = pool.get_colorf( 1.0, 1.0, 1.0, 1.0 )
		
		-- If you got a new high score, show it in red.
		if score >= high_score then
			high_score = score
			text.color = pool.get_colorf( 1.0, 0.0, 0.0, 1.0 )
		end
	
		text.value = score
	end
	
	-- High score text.
	do
		local text = owner:spawn( chunks.ticker.spawn() )
		
		text.location = pool.get_v3f( 78.0, 34.0, 1.0 )
		text.scale    = pool.get_v3f( 0.6, 0.6, 0.6 )
		text.color    = pool.get_colorf( 1.0, 0.0, 0.0, 1.0 )	
		text.value    = high_score
	end

	-- Menu button.
	do
		local on_release = function( inner )
			self:transitionOut( function( o ) game.lua:onQuit() end )
		end
	
		local button = self:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_TR, Anchor.Anchor_TR, pool.get_v3f( -5.0, -10.0, 1.0 ) )
		
		textures.setTexture( button, assets.textures.menu_button )
	end	
	
	local y_offset = -15.0 
	local spacer   = 50.0
	
	-- Facebook button.
	do
		local on_release = function( inner )
			events.on_facebook( game )
		end
	
		local button = self:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_C, Anchor.Anchor_C, 
		                        pool.get_v3f( -1.0 * spacer / 2.0, y_offset, 1.0 ) )
		
		textures.setTexture( button, assets.textures.facebook_button )
	end
	
	-- Leaderboards button.
	do
		local on_release = function( inner )
			events.on_leaderboard_theme( game )
		end
	
		local button = self:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_C, Anchor.Anchor_C, 
		                        pool.get_v3f( -1.0 * spacer / 2.0 - spacer, y_offset, 1.0 ) )
		
		textures.setTexture( button, assets.textures.leaderboards_button )
	end
	
	-- Twitter button.
	do
		local on_release = function( inner )
			events.on_twitter( game )
		end
	
		local button = self:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_C, Anchor.Anchor_C, 
		                        pool.get_v3f( spacer / 2.0, y_offset, 1.0 ) )
		
		textures.setTexture( button, assets.textures.twitter_button )
	end
	
	-- Email button.
	do
		local on_release = function( inner )
			events.on_email( game )
		end
	
		local button = self:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_C, Anchor.Anchor_C, 
		                        pool.get_v3f( spacer / 2.0 + spacer, y_offset, 1.0 ) )
		
		textures.setTexture( button, assets.textures.email_button )
	end
	
	-- Replay button.
	do
		local on_release = function( owner )
			self:transitionOut( function( o ) game.lua:onReplay() end )
		end
		
		local button = self:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_C, Anchor.Anchor_C, 
		                        pool.get_v3f( -27.0, -78.0, 1.0 ) )
		                        
		textures.setTexture( button, assets.textures.replay_button )

		-- Setup a bobbing action.
		do
			local l = LoopAction()
			
			l:addAction( ScaleAction( 0.4, InterpAction.Smooth, pool.get_v3f( 1.1, 1.1, 1.0 ) ) )
			l:addAction( ScaleAction( 0.4, InterpAction.Smooth, pool.get_v3f( 1.0, 1.0, 1.0 ) ) )
			
			button:addAction( l )
		end
	end
	
	-- Play death sound.
	sound.play( assets.sounds.die )
	
	-- Transition in.
	self:transitionIn()
end

-- Transition in.
function LuaDeathMenu:transitionIn()
	local game = self.owner:getGame()
	local s    = SequenceAction()
	local s2   = SplitAction()
	local f    = function( inner )
		events.on_game_over( game )
	end
	
	s:addAction( ScaleAction( 0.0, InterpAction.Smooth, pool.get_v3f( 0.0, 0.0, 1.0 ) ) )
	s:addAction( RotateOffsetAction( 0.0, InterpAction.Smooth, pool.get_v3f( 0.0, 0.0, -180.0 ) ) )
	s:addAction( AlphaAction( 0.0, InterpAction.Smooth, 0.0 ) )
	s2:addAction( ScaleAction( 0.4, InterpAction.Smooth, pool.get_v3f( 1.0, 1.0, 1.0 ) ) )
	s2:addAction( RotateOffsetAction( 0.4, InterpAction.Smooth, pool.get_v3f( 0.0, 0.0, 180.0 ) ) )
	s2:addAction( AlphaAction( 0.4, InterpAction.Smooth, 1.0 ) )
	s:addAction( s2 )
	s:addAction( LuaAction( 0.0, f ) )
	
	self.owner:addAction( s )
end

-- Transition out.
function LuaDeathMenu:transitionOut( callback )
	local s  = SequenceAction()
	local s2 = SplitAction()
	
	s2:addAction( ScaleAction( 0.4, InterpAction.Smooth, pool.get_v3f( 0.0, 0.0, 1.0 ) ) )
	s2:addAction( RotateOffsetAction( 0.4, InterpAction.Smooth, pool.get_v3f( 0.0, 0.0, -180.0 ) ) )
	s2:addAction( AlphaAction( 0.4, InterpAction.Smooth, 0.0 ) )
	s:addAction( s2 )
	s:addAction( LuaAction( 0.0, callback ) )
	s:addAction( DestroyAction( 0.0 ) )
	
	self.owner:addAction( s )
end
