------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Hud                --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine   = engine.instance
local chunks   = engine.chunks
local assets   = chunks.assets
local pool     = chunks.pool
local textures = chunks.textures

-- LuaHud --
LuaHud = chunks.class.inherit( chunks.window.LuaWindow )
{
	ticker = nil,
	meter  = nil
}
	
-- The spawner.
spawn = chunks.class.spawner( Dialog, LuaHud )

-- The created method.
function LuaHud:created( owner )
	local game = owner:getGame()
	
	-- Initialize owner.
	owner.location = pool.get_v3f( 0.0, 0.0, 100.0 )
	owner.size     = game.window_camera.world_size
	owner.hidden   = true
	
	-- The score bar.
	local score_bar = nil	
	
	do
		score_bar = owner:spawn( Window() )
		
		score_bar.anchor = Anchor( Anchor.Anchor_BL, Anchor.Anchor_BL, pool.get_v3f( -5.0, 0.0, 0.0 ) )
		
		textures.setTexture( score_bar, assets.textures.score_bar )
	end

	do
		black_box = owner:spawn( Window() )

		black_box.anchor = Anchor( Anchor.Anchor_TL, Anchor.Anchor_TL, pool.get_v3f( 0.0, 0.0, 0.0 ) )
		textures.setTexture( black_box, { path = "builtin://white", size = v2f( 320, 50 ) } )
		black_box.color    = pool.get_colorf( 0.0, 0.0, 0.0, 1.0 )	

		local s = SequenceAction()
		s:addAction( DestroyAction( 1 ) )
		black_box:addAction( s )
	end

	-- The ticker.
	do
		local ticker = score_bar:spawn( chunks.ticker.spawn() )
		
		ticker.location = pool.get_v3f( 0.0, -2.0, 1.0 )
		ticker.scale    = pool.get_v3f( 0.75, 0.75, 1.0 )
		
		self.ticker = ticker
	end
	
	-- Bonus indicator.
	do
		local meter = score_bar:spawn( chunks.bonusmeter.spawn() )
		
		meter.location = pool.get_v3f( 0.0, 35.0, 0.0 )
		
		self.meter = meter
	end  
	
	-- The pause button.
	do
		-- Bring up the pause menu.
		local on_release = function( inner )
			game.lua:onPause()
		end	
	
		local button = self:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_BR, Anchor.Anchor_BR, pool.get_v3f( 0.0, 0.0, 0.0 ) )
		
		textures.setTexture( button, assets.textures.pause_button )
	end
end


