------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Pause Menu         --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine   = engine.instance
local chunks   = engine.chunks
local assets   = chunks.assets
local pool     = chunks.pool
local textures = chunks.textures

-- LuaPauseMenu --
LuaPauseMenu = chunks.class.inherit( chunks.window.LuaWindow )()

-- The spawner.
spawn = chunks.class.spawner( Dialog, LuaPauseMenu )

-- The created event.
function LuaPauseMenu:created( owner )
	local game = owner:getGame()
	local menu = nil
	
	-- Initialize owner.
	owner.location = pool.get_v3f( 0.0, 0.0, 10.0 )
	owner.size     = game.window_camera.world_size
	owner.hidden   = true

	-- Menu: we anchor it to an inner shell to 
	--       make the animations easier.
	do
		local shell = owner:spawn( Window() )
		
		shell.hidden = true
		shell.anchor = Anchor( Anchor.Anchor_B, Anchor.Anchor_B, pool.get_v3f( 0.0, 0.0, 0.0 ) )
		menu         = shell:spawn( chunks.window.spawn( Window() ) )
		
		textures.setTexture( menu, assets.textures.pause_menu )
		
		shell.size = menu.size
	end

	local pause_menu = self;
	engine.onBackButton = function()
		engine.onBackButton = function() end;
		pause_menu:transitionOut( function( o ) game.lua:onUnpause() end )
	end

	-- Play button.
	do
		-- Transition out and unpause.
		local on_release = function( inner )
			self:transitionOut( function( o ) game.lua:onUnpause() end )
		end
		
		local button = menu.lua:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_C, Anchor.Anchor_C, pool.get_v3f( 0.0, 40.0, 1.0 ) )
		textures.setTexture( button, assets.textures.continue_button )
	end
	
	-- Quit button.
	do
		-- Transition out and unpause.
		local on_release = function( inner )
			self:transitionOut( function( o ) game.lua:onQuit() end )
		end
		
		local button = menu.lua:addButton( on_release )
		
		button.anchor = Anchor( Anchor.Anchor_C, Anchor.Anchor_C, pool.get_v3f( 0.0, -60.0, 1.0 ) )
		textures.setTexture( button, assets.textures.menu_button )
	end
	
	-- Transition in.
	self:transitionIn()
end

-- Transition in.
function LuaPauseMenu:transitionIn()
	local height = self.owner.size.y
	local s      = SequenceAction()	
	local s2     = SplitAction()
	
	s:addAction( MoveOffsetAction( 0.0, InterpAction.Smooth, pool.get_v3f( 0.0, -height, 0.0 ) ) )
	s:addAction( AlphaAction( 0.0, InterpAction.Smooth, 0.0 ) )
	s2:addAction( MoveOffsetAction( 0.4, InterpAction.Smooth, pool.get_v3f( 0.0,  height, 0.0 ) ) )
	s2:addAction( AlphaAction( 0.4, InterpAction.Smooth, 1.0 ) )
	s:addAction( s2 )
	
	self.owner:addAction( s )
end

-- Transition out.
function LuaPauseMenu:transitionOut( callback )
	local height = self.owner.size.y
	local s      = SequenceAction()	
	local s2     = SplitAction()
	
	s2:addAction( MoveOffsetAction( 0.4, InterpAction.Smooth, pool.get_v3f( 0.0, -height, 0.0 ) ) )
	s2:addAction( AlphaAction( 0.4, InterpAction.Smooth, 0.0 ) )
	s:addAction( s2 )
	s:addAction( LuaAction( 0.0, callback ) )
	s:addAction( DestroyAction( 0.0 ) )
	
	self.owner:addAction( s )
end
