------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- New High Score     --
------------------------

-- module --
module(...,package.seeall)

-- includes --
local engine    = engine.instance
local chunks    = engine.chunks
local assets    = chunks.assets
local pool      = chunks.pool
local enemy     = chunks.enemy
local particles = chunks.particles
local actions   = chunks.actions
local textures  = chunks.textures
local sound     = chunks.sound

-- LuaNewHighScore --
LuaNewHighScore = chunks.class.inherit( chunks.enemy.LuaEnemy )()

-- The spawner.
spawn = chunks.class.spawner( ActorBase, LuaNewHighScore )

-- The created method.
function LuaNewHighScore:created( owner )
	-- Initialize super.
	enemy.LuaEnemy.created( self, owner )
	
	-- Initialize owner.
	owner.label = "new_high_score"
	
	-- Balcony.
	do
		local actor = owner:spawn( SpriteActor() )
		
		textures.setTexture( actor, assets.textures.new_high_score )

		self.visuals.new_high_score = actor
	end
	
	self:setVisual( "new_high_score" )
end

-- Play back the celebration animation.
function LuaNewHighScore:celebrate()
	local game  = self.owner:getGame()
	local root  = game.lua.root
	local delay = 0.4
	
	-- Do camera zoom.
	do
		local s = SequenceAction()
		
		s:addAction( SleepAction( delay ) )
		s:addAction( ScaleAction( 0.5, InterpAction.Smooth, pool.get_v3f( 1.1, 1.1, 1.0 ) ) )
		s:addAction( SleepAction( 0.3 ) )
		s:addAction( ScaleAction( 0.5, InterpAction.Smooth, pool.get_v3f( 1.0, 1.0, 1.0 ) ) )
		
		root:clearActions()
		root:addAction( s )
	end
	
	-- Do slo mo.
	do
		local scene = game:getScene()
		local s     = SequenceAction()
		
		s:addAction( SleepAction( delay ) )
		s:addAction( DeltaTimeAction( 1.0, InterpAction.Smooth, 0.2 ) )
		s:addAction( DeltaTimeAction( 1.0, InterpAction.Smooth, 1.0 ) )
		
		scene:clearActions()
		scene:addAction( s )
	end
	
	-- Fireworks spawner.
	local fireworks = function( inner, location )
		local explosion = particles.spawn_big( root, 
		                                       assets.textures.particles_spark, 
		                                       location )
		local x = math.random()
		
		-- Set explosion color.
		if x < 0.2 then
			explosion.color = pool.get_colorf( 195.0 / 255.0, 24.0 / 255.0, 181.0 / 255.0, 1.0 ) -- purple
		elseif x < 0.4 then
			explosion.color = pool.get_colorf( 255.0 / 255.0, 109.0 / 255.0, 23.0 / 255.0, 1.0 ) -- orange
		elseif x < 0.6 then
			explosion.color = pool.get_colorf( 255.0 / 255.0, 230.0 / 255.0, 23.0 / 255.0, 1.0 ) -- yellow
		elseif x < 0.8 then
			explosion.color = pool.get_colorf( 77.0 / 255.0, 255.0 / 255.0, 23.0 / 255.0, 1.0 ) -- green
		else
			explosion.color = pool.get_colorf( 28.0 / 255.0, 23.0 / 255.0, 255.0 / 255.0, 1.0 ) -- blue
		end
		
		-- Play sound.
		sound.play_random( assets.sounds.explode )
	end
	
	-- Spawn fireworks.
	do
		local s = SequenceAction()
		local z = self.visual:getWorldLocation().z + 1.0
		local x = 100
		local y = 80
		
		s:addAction( SleepAction( delay ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f( -x, -y * 2, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  0, -y * 2, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  x, -y * 2, z ) ) )
		s:addAction( SleepAction( 0.2 ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f( -x, -y, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  0, -y, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  x, -y, z ) ) )
		s:addAction( SleepAction( 0.1 ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f( -x, 0, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  0, 0, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  x, 0, z ) ) )
		s:addAction( SleepAction( 0.1 ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f( -x, y, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  0, y, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  x, y, z ) ) )
		s:addAction( SleepAction( 0.1 ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f( -x, y * 2, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  0, y * 2, z ) ) )
		s:addAction( LuaAction( 0.0, fireworks, v3f(  x, y * 2, z ) ) )
	
		self.owner:addAction( s )
	end
end



