------------------------
-- Kevin Depue (2010) --
-- Backflip Studios   --
--                    --
-- Scenario           --
------------------------

module(...,package.seeall)

-- includes --
local engine = engine.instance
local chunks = engine.chunks
local pool   = chunks.pool

-- LuaScenario --
LuaScenario = chunks.class.new()

-- The spawner.
spawn = chunks.class.spawner( ActorBase, LuaScenario )

-- The created method.
function LuaScenario:created( owner )
	owner.label = "scenario"
end

-- Mirror a scenario.
function LuaScenario:mirror()
	local owner = self.owner
	
	for i = 0,owner:getNumOwned() do
		local child = owner:getOwned( i )
			
		if child and child.label == "scenario" then
			child.rotation = pool.get_v3f( 0.0, 180.0, 0.0 )
		end
	end
end

-- Scroll a scenario.
function LuaScenario:scroll( factor, z )
	local owner    = self.owner
	local game     = owner:getGame()
	local start    = game.scene_camera.world_size.y * 0.75
	local target   = game.scene_camera.world_size.y * factor
	local lifetime = math.abs( start - target ) / math.abs( game.lua.speed )
	
	-- Set start location.
	owner.location = pool.get_v3f( 0.0, start, z )

	-- Setup the movement action.
	do
		local s = SequenceAction()
		
		s:addAction( MoveAction( lifetime, InterpAction.Lerp, pool.get_v3f( 0.0, target, z ) ) )
		
		owner:clearActions()
		owner:addAction( s )
	end
	
	return lifetime
end

